<?php

if ( ! function_exists('blu_elated_blog_options_map') ) {

	function blu_elated_blog_options_map() {

		blu_elated_add_admin_page(
			array(
				'slug' => '_blog_page',
				'title' => esc_html__('Blog', 'blu'),
				'icon' => 'fa fa-files-o'
			)
		);

		/**
		 * Blog Lists
		 */
		$panel_blog_lists = blu_elated_add_admin_panel(
			array(
				'page' => '_blog_page',
				'name' => 'panel_blog_lists',
				'title' => esc_html__('Blog Lists', 'blu')
			)
		);

		blu_elated_add_admin_field(array(
			'name'        => 'blog_list_type',
			'type'        => 'select',
			'label'       => esc_html__('Blog Layout for Archive Pages', 'blu'),
			'description' => esc_html__('Choose a default blog layout', 'blu'),
			'default_value' => 'standard',
			'parent'      => $panel_blog_lists,
			'options'     => array(
				'standard'			 => esc_html__('Blog: Standard', 'blu'),
				'masonry' 			 => esc_html__('Blog: Masonry', 'blu'),
				'masonry-full-width' => esc_html__('Blog: Masonry Full Width', 'blu')
			)
		));

		blu_elated_add_admin_field(array(
			'name'        => 'archive_sidebar_layout',
			'type'        => 'select',
			'label'       => esc_html__('Archive and Category Sidebar', 'blu'),
			'description' => esc_html__('Choose a sidebar layout for archived blog post lists and category blog lists', 'blu'),
			'parent'      => $panel_blog_lists,
			'options'     => array(
				'default'			=> esc_html__('No Sidebar', 'blu'),
				'sidebar-33-right'	=> esc_html__('Sidebar 1/3 Right', 'blu'),
				'sidebar-25-right' 	=> esc_html__('Sidebar 1/4 Right', 'blu'),
				'sidebar-33-left' 	=> esc_html__('Sidebar 1/3 Left', 'blu'),
				'sidebar-25-left' 	=> esc_html__('Sidebar 1/4 Left', 'blu')
			)
		));
		
		$blu_elated_custom_sidebars = blu_elated_get_custom_sidebars();
		if(count($blu_elated_custom_sidebars) > 0) {
			blu_elated_add_admin_field(array(
				'name' => 'blog_custom_sidebar',
				'type' => 'selectblank',
				'label' => esc_html__('Sidebar to Display', 'blu'),
				'description' => esc_html__('Choose a sidebar to display on blog post lists and category blog lists. Default sidebar is "Sidebar Page"', 'blu'),
				'parent' => $panel_blog_lists,
				'options' => blu_elated_get_custom_sidebars()
			));
		}

		blu_elated_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'pagination',
				'default_value' => 'yes',
				'label' => esc_html__('Pagination', 'blu'),
				'description' => esc_html__('Enabling this option will display pagination links on bottom of blog post list', 'blu'),
				'parent' => $panel_blog_lists,
				'args' => array(
					'dependence' => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#eltdf_eltdf_pagination_container'
				)
			)
		);

		$pagination_container = blu_elated_add_admin_container(
			array(
				'name' => 'eltdf_pagination_container',
				'hidden_property' => 'pagination',
				'hidden_value' => 'no',
				'parent' => $panel_blog_lists,
			)
		);

		blu_elated_add_admin_field(
			array(
				'parent' => $pagination_container,
				'type' => 'text',
				'name' => 'blog_page_range',
				'default_value' => '4',
				'label' => esc_html__('Pagination Range Limit', 'blu'),
				'description' => esc_html__('Enter a number that will limit pagination to a certain range of links', 'blu'),
				'args' => array(
					'col_width' => 3
				)
			)
		);

		blu_elated_add_admin_field(array(
			'name'        => 'masonry_pagination',
			'type'        => 'select',
			'label'       => esc_html__('Pagination on Masonry', 'blu'),
			'description' => esc_html__('Choose a pagination style for Masonry Blog List', 'blu'),
			'parent'      => $pagination_container,
			'default_value' => 'standard',
			'options'     => array(
				'standard'			=> esc_html__('Standard', 'blu'),
				'load-more'			=> esc_html__('Load More', 'blu')
			),
		));

        blu_elated_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'enable_load_more_pag',
				'default_value' => 'no',
				'label' => esc_html__('Load More Pagination on Other Lists', 'blu'),
				'description' => esc_html__('Enable Load More Pagination on other lists', 'blu'),
				'parent' => $pagination_container,
				'args' => array(
					'col_width' => 3
				)
			)
		);
	
		blu_elated_add_admin_field(
			array(
				'type' => 'text',
				'name' => 'number_of_chars',
				'default_value' => '',
				'label' => esc_html__('Number of Words in Excerpt', 'blu'),
				'description' => esc_html__('Enter a number of words in excerpt (article summary)', 'blu'),
				'parent' => $panel_blog_lists,
				'args' => array(
					'col_width' => 3
				)
			)
		);

		blu_elated_add_admin_field(
			array(
				'type' => 'text',
				'name' => 'standard_number_of_chars',
				'default_value' => '',
				'label' => esc_html__('Standard Type Number of Words in Excerpt', 'blu'),
				'description' => esc_html__('Enter a number of words in excerpt (article summary)', 'blu'),
				'parent' => $panel_blog_lists,
				'args' => array(
					'col_width' => 3
				)
			)
		);

		blu_elated_add_admin_field(
			array(
				'type' => 'text',
				'name' => 'masonry_number_of_chars',
				'default_value' => '',
				'label' => esc_html__('Masonry Type Number of Words in Excerpt', 'blu'),
				'description' => esc_html__('Enter a number of words in excerpt (article summary)', 'blu'),
				'parent' => $panel_blog_lists,
				'args' => array(
					'col_width' => 3
				)
			)
		);

		blu_elated_add_admin_field(array(
			'name'          => 'blog_list_feature_image',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Feature Image', 'blu'),
			'description'   => esc_html__('Enabling this option will show feature image for your posts on your blog page', 'blu'),
			'parent'        => $panel_blog_lists,
			'default_value' => 'yes',
		));

		blu_elated_add_admin_field(array(
			'name'          => 'blog_list_category',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Category', 'blu'),
			'description'   => esc_html__('Enabling this option will show category post info on your blog page', 'blu'),
			'parent'        => $panel_blog_lists,
			'default_value' => 'yes'
		));

		blu_elated_add_admin_field(array(
			'name'          => 'blog_list_date',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Date', 'blu'),
			'description'   => esc_html__('Enabling this option will show date post info on your blog page', 'blu'),
			'parent'        => $panel_blog_lists,
			'default_value' => 'yes'
		));

		blu_elated_add_admin_field(array(
			'name'          => 'blog_list_author',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Author', 'blu'),
			'description'   => esc_html__('Enabling this option will show author post info on your blog page', 'blu'),
			'parent'        => $panel_blog_lists,
			'default_value' => 'yes'
		));

		blu_elated_add_admin_field(array(
			'name'          => 'blog_list_comment',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Comments', 'blu'),
			'description'   => esc_html__('Enabling this option will show comments post info on your blog page', 'blu'),
			'parent'        => $panel_blog_lists,
			'default_value' => 'yes'
		));

		blu_elated_add_admin_field(array(
			'name'          => 'blog_list_like',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Like', 'blu'),
			'description'   => esc_html__('Enabling this option will show like post info on your blog page', 'blu'),
			'parent'        => $panel_blog_lists,
			'default_value' => 'yes'
		));

		blu_elated_add_admin_field(array(
			'name'          => 'blog_list_share',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Share', 'blu'),
			'description'   => esc_html__('Enabling this option will show share post info on your blog page', 'blu'),
			'parent'        => $panel_blog_lists,
			'default_value' => 'no'
		));

		blu_elated_add_admin_field(array(
			'name'          => 'blog_list_tags',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Tags', 'blu'),
			'description'   => esc_html__('Enabling this option will show post tags on your blog page', 'blu'),
			'parent'        => $panel_blog_lists,
			'default_value' => 'no'
		));

		/**
		 * Blog Single
		 */
		$panel_blog_single = blu_elated_add_admin_panel(
			array(
				'page' => '_blog_page',
				'name' => 'panel_blog_single',
				'title' => esc_html__('Blog Single', 'blu')
			)
		);

		blu_elated_add_admin_field(array(
			'name'        => 'blog_single_sidebar_layout',
			'type'        => 'select',
			'label'       => esc_html__('Sidebar Layout', 'blu'),
			'description' => esc_html__('Choose a sidebar layout for Blog Single pages', 'blu'),
			'parent'      => $panel_blog_single,
			'options'     => array(
				'default'			=> esc_html__('No Sidebar', 'blu'),
				'sidebar-33-right'	=> esc_html__('Sidebar 1/3 Right', 'blu'),
				'sidebar-25-right' 	=> esc_html__('Sidebar 1/4 Right', 'blu'),
				'sidebar-33-left' 	=> esc_html__('Sidebar 1/3 Left', 'blu'),
				'sidebar-25-left' 	=> esc_html__('Sidebar 1/4 Left', 'blu')
			),
			'default_value'	=> 'default'
		));


		if(count($blu_elated_custom_sidebars) > 0) {
			blu_elated_add_admin_field(array(
				'name' => 'blog_single_custom_sidebar',
				'type' => 'selectblank',
				'label' => esc_html__('Sidebar to Display', 'blu'),
				'description' => esc_html__('Choose a sidebar to display on Blog Single pages. Default sidebar is "Sidebar"', 'blu'),
				'parent' => $panel_blog_single,
				'options' => blu_elated_get_custom_sidebars()
			));
		}

		blu_elated_add_admin_field(array(
			'name'          => 'blog_single_title_in_title_area',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Post Title in Title Area', 'blu'),
			'description'   => esc_html__('Enabling this option will show post title in title area on single post pages', 'blu'),
			'parent'        => $panel_blog_single,
			'default_value' => 'no'
		));

		blu_elated_add_admin_field(
			array(
				'type' => 'text',
				'name' => 'blog_single_feature_image_max_width',
				'label' => esc_html__('Featured Image Max Width', 'blu'),
				'description' => esc_html__('Define maximum width for featured image on single post pages. Default value is 1100', 'blu'),
				'parent' => $panel_blog_single,
				'args' => array(
					'col_width' => 3
				)
			)
		);

		blu_elated_add_admin_field(array(
			'name'          => 'blog_single_category',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Category', 'blu'),
			'description'   => esc_html__('Enabling this option will show category post info on your single post page', 'blu'),
			'parent'        => $panel_blog_single,
			'default_value' => 'yes'
		));

		blu_elated_add_admin_field(array(
			'name'          => 'blog_single_date',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Date', 'blu'),
			'description'   => esc_html__('Enabling this option will show date post info on your single post page', 'blu'),
			'parent'        => $panel_blog_single,
			'default_value' => 'yes'
		));

		blu_elated_add_admin_field(array(
			'name'          => 'blog_single_author',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Author', 'blu'),
			'description'   => esc_html__('Enabling this option will show author post info on your single post page', 'blu'),
			'parent'        => $panel_blog_single,
			'default_value' => 'yes'
		));

		blu_elated_add_admin_field(array(
			'name'          => 'blog_single_comment',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Comments', 'blu'),
			'description'   => esc_html__('Enabling this option will show comments post info on your single post page', 'blu'),
			'parent'        => $panel_blog_single,
			'default_value' => 'yes'
		));

		blu_elated_add_admin_field(array(
			'name'          => 'blog_single_like',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Like', 'blu'),
			'description'   => esc_html__('Enabling this option will show like post info on your single post page', 'blu'),
			'parent'        => $panel_blog_single,
			'default_value' => 'yes'
		));

		blu_elated_add_admin_field(array(
			'name'          => 'blog_single_share',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Share', 'blu'),
			'description'   => esc_html__('Enabling this option will show share post info on your single post page', 'blu'),
			'parent'        => $panel_blog_single,
			'default_value' => 'yes'
		));

		blu_elated_add_admin_field(array(
			'name'          => 'blog_single_tags',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Tags', 'blu'),
			'description'   => esc_html__('Enabling this option will show post tags on your single post page', 'blu'),
			'parent'        => $panel_blog_single,
			'default_value' => 'yes'
		));

		blu_elated_add_admin_field(array(
			'name'			=> 'blog_single_related_posts',
			'type'			=> 'yesno',
			'label'			=> esc_html__('Show Related Posts', 'blu'),
			'description'   => esc_html__('Enabling this option will show related posts on your single post page', 'blu'),
			'parent'        => $panel_blog_single,
			'default_value' => 'yes',
			'args' => array(
				'dependence' => true,
				'dependence_hide_on_yes' => '',
				'dependence_show_on_yes' => '#eltdf_related_image_container'
			)
		));

		$related_image_container = blu_elated_add_admin_container(
			array(
				'name' => 'related_image_container',
				'hidden_property' => 'blog_single_related_posts',
				'hidden_value' => 'no',
				'parent' => $panel_blog_single,
			)
		);

		blu_elated_add_admin_field(
			array(
				'type' => 'text',
				'name' => 'blog_single_related_image_size',
				'label' => esc_html__('Related Posts Image Max Width', 'blu'),
				'description' => esc_html__('Define maximum width for related posts images on your single post pages. Default value is 1100', 'blu'),
				'parent' => $related_image_container,
				'args' => array(
					'col_width' => 3
				)
			)
		);

		blu_elated_add_admin_field(array(
			'name'          => 'blog_single_comments',
			'type'          => 'yesno',
			'label'         => esc_html__('Show Comments Form', 'blu'),
			'description'   => esc_html__('Enabling this option will show comments form on your page', 'blu'),
			'parent'        => $panel_blog_single,
			'default_value' => 'yes'
		));

		blu_elated_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'blog_single_navigation',
				'default_value' => 'no',
				'label' => esc_html__('Enable Prev/Next Single Post Navigation Links', 'blu'),
				'description' => esc_html__('Enable navigation links through the blog posts (left and right arrows will appear)', 'blu'),
				'parent' => $panel_blog_single,
				'args' => array(
					'dependence' => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#eltdf_eltdf_blog_single_navigation_container'
				)
			)
		);

		$blog_single_navigation_container = blu_elated_add_admin_container(
			array(
				'name' => 'eltdf_blog_single_navigation_container',
				'hidden_property' => 'blog_single_navigation',
				'hidden_value' => 'no',
				'parent' => $panel_blog_single,
			)
		);

		blu_elated_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'blog_navigation_through_same_category',
				'default_value' => 'no',
				'label'       => esc_html__('Enable Navigation Only in Current Category', 'blu'),
				'description' => esc_html__('Limit your navigation only through current category', 'blu'),
				'parent'      => $blog_single_navigation_container,
				'args' => array(
					'col_width' => 3
				)
			)
		);

		blu_elated_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'blog_author_info',
				'default_value' => 'yes',
				'label' => esc_html__('Show Author Info Box', 'blu'),
				'description' => esc_html__('Enabling this option will display author name and descriptions on Blog Single pages', 'blu'),
				'parent' => $panel_blog_single,
				'args' => array(
					'dependence' => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#eltdf_eltdf_blog_single_author_info_container'
				)
			)
		);

		$blog_single_author_info_container = blu_elated_add_admin_container(
			array(
				'name' => 'eltdf_blog_single_author_info_container',
				'hidden_property' => 'blog_author_info',
				'hidden_value' => 'no',
				'parent' => $panel_blog_single,
			)
		);

		blu_elated_add_admin_field(
			array(
				'type'        => 'yesno',
				'name' => 'blog_author_info_email',
				'default_value' => 'no',
				'label'       => esc_html__('Show Author Email', 'blu'),
				'description' => esc_html__('Enabling this option will show author email', 'blu'),
				'parent'      => $blog_single_author_info_container,
				'args' => array(
					'col_width' => 3
				)
			)
		);

		blu_elated_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'blog_single_author_social',
				'default_value' => 'yes',
				'label'       => esc_html__('Show Author Social Icons', 'blu'),
				'description' => esc_html__('Enabling this option will show author social icons on your single post page', 'blu'),
				'parent'      => $blog_single_author_info_container,
				'args' => array(
					'col_width' => 3
				)
			)
		);
	}

	add_action( 'blu_elated_options_map', 'blu_elated_blog_options_map', 11);
}