<?php

if ( ! function_exists('blu_elated_footer_options_map') ) {
	/**
	 * Add footer options
	 */
	function blu_elated_footer_options_map() {

		blu_elated_add_admin_page(
			array(
				'slug' => '_footer_page',
				'title' => esc_html__('Footer', 'blu'),
				'icon' => 'fa fa-sort-amount-asc'
			)
		);

		$footer_panel = blu_elated_add_admin_panel(
			array(
				'title' => esc_html__('Footer', 'blu'),
				'name' => 'footer',
				'page' => '_footer_page'
			)
		);

		blu_elated_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'footer_in_grid',
				'default_value' => 'no',
				'label' => esc_html__('Footer in Grid', 'blu'),
				'description' => esc_html__('Enabling this option will place Footer content in grid', 'blu'),
				'parent' => $footer_panel,
			)
		);

		blu_elated_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'show_footer_top',
				'default_value' => 'yes',
				'label' => esc_html__('Show Footer Top', 'blu'),
				'description' => esc_html__('Enabling this option will show Footer Top area', 'blu'),
				'args' => array(
					'dependence' => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#eltdf_show_footer_top_container'
				),
				'parent' => $footer_panel,
			)
		);

		$show_footer_top_container = blu_elated_add_admin_container(
			array(
				'name' => 'show_footer_top_container',
				'hidden_property' => 'show_footer_top',
				'hidden_value' => 'no',
				'parent' => $footer_panel
			)
		);

		blu_elated_add_admin_field(
			array(
				'type' => 'select',
				'name' => 'footer_top_columns',
				'default_value' => '4',
				'label' => esc_html__('Footer Top Columns', 'blu'),
				'description' => esc_html__('Choose number of columns for Footer Top area', 'blu'),
				'options' => array(
					'1' => '1',
					'2' => '2',
					'3' => '3',
					'4' => '4',
					'5' => '3(25%+25%+50%)',
					'6' => '3(50%+25%+25%)'
				),
				'parent' => $show_footer_top_container,
			)
		);

		blu_elated_add_admin_field(
			array(
				'type' => 'select',
				'name' => 'footer_top_columns_alignment',
				'default_value' => '',
				'label' => esc_html__('Footer Top Columns Alignment', 'blu'),
				'description' => esc_html__('Text Alignment in Footer Columns', 'blu'),
				'options' => array(
					'' => esc_html__('Default', 'blu'),
					'left' => esc_html__('Left', 'blu'),
					'center' => esc_html__('Center', 'blu'),
					'right' => esc_html__('Right', 'blu')
				),
				'parent' => $show_footer_top_container,
			)
		);

		blu_elated_add_admin_field(array(
			'name' => 'footer_top_background_color',
			'type' => 'color',
			'label' => esc_html__('Background Color', 'blu'),
			'description' => esc_html__('Set background color for top footer area', 'blu'),
			'parent' => $show_footer_top_container
		));

		blu_elated_add_admin_field(
			array(
				'type' => 'yesno',
				'name' => 'show_footer_bottom',
				'default_value' => 'yes',
				'label' => esc_html__('Show Footer Bottom', 'blu'),
				'description' => esc_html__('Enabling this option will show Footer Bottom area', 'blu'),
				'args' => array(
					'dependence' => true,
					'dependence_hide_on_yes' => '',
					'dependence_show_on_yes' => '#eltdf_show_footer_bottom_container'
				),
				'parent' => $footer_panel,
			)
		);

		$show_footer_bottom_container = blu_elated_add_admin_container(
			array(
				'name' => 'show_footer_bottom_container',
				'hidden_property' => 'show_footer_bottom',
				'hidden_value' => 'no',
				'parent' => $footer_panel
			)
		);

		blu_elated_add_admin_field(
			array(
				'type' => 'select',
				'name' => 'footer_bottom_columns',
				'default_value' => '4',
				'label' => esc_html__('Footer Bottom Columns', 'blu'),
				'description' => esc_html__('Choose number of columns for Footer Bottom area', 'blu'),
				'options' => array(
					'1' => '1',
					'2' => '2',
					'3' => '3'
				),
				'parent' => $show_footer_bottom_container,
			)
		);

		blu_elated_add_admin_field(
			array(
				'type' => 'select',
				'name' => 'footer_bottom_columns_alignment',
				'default_value' => '',
				'label' => esc_html__('Footer Bottom Columns Alignment', 'blu'),
				'description' => esc_html__('Text Alignment in Footer Columns', 'blu'),
				'options' => array(
					'' => esc_html__('Default', 'blu'),
					'left' => esc_html__('Left', 'blu'),
					'center' => esc_html__('Center', 'blu'),
					'right' => esc_html__('Right', 'blu')
				),
				'parent' => $show_footer_bottom_container,
			)
		);

		blu_elated_add_admin_field(array(
			'name' => 'footer_bottom_height',
			'type' => 'text',
			'label' => esc_html__('Height', 'blu'),
			'description' => esc_html__('Enter footer bottom bar height (Default is 60)', 'blu'),
			'parent' => $show_footer_bottom_container,
			'args' => array(
				'col_width' => 2,
				'suffix' => 'px'
			)
		));

		blu_elated_add_admin_field(array(
			'name' => 'footer_bottom_background_color',
			'type' => 'color',
			'label' => esc_html__('Background Color', 'blu'),
			'description' => esc_html__('Set background color for bottom footer area', 'blu'),
			'parent' => $show_footer_bottom_container
		));

		blu_elated_add_admin_field(array(
			'name' => 'footer_bottom_border_top_color',
			'type' => 'color',
			'label' => esc_html__('Border Top Color', 'blu'),
			'description' => esc_html__('Set border top color for bottom footer area', 'blu'),
			'parent' => $show_footer_bottom_container
		));
	}

	add_action( 'blu_elated_options_map', 'blu_elated_footer_options_map', 9);
}