<?php

if ( ! function_exists('blu_elated_header_options_map') ) {

	function blu_elated_header_options_map() {

		blu_elated_add_admin_page(
			array(
				'slug' => '_header_page',
				'title' => esc_html__('Header', 'blu'),
				'icon' => 'fa fa-header'
			)
		);

		$panel_header = blu_elated_add_admin_panel(
			array(
				'page' => '_header_page',
				'name' => 'panel_header',
				'title' => esc_html__('Header', 'blu')
			)
		);

		blu_elated_add_admin_field(
			array(
				'parent' => $panel_header,
				'type' => 'radiogroup',
				'name' => 'header_type',
				'default_value' => 'header-standard',
				'label' => esc_html__('Choose Header Type', 'blu'),
				'description' => esc_html__('Select the type of header you would like to use', 'blu'),
				'options' => array(
					'header-standard' => array(
						'image' => ELATED_FRAMEWORK_ADMIN_ASSETS_ROOT.'/img/header-standard.png'
					),
                    'header-full-screen' => array(
                        'image' => ELATED_FRAMEWORK_ADMIN_ASSETS_ROOT.'/img/header-full-screen.png'
                    ),
					'header-vertical' => array(
						'image' => ELATED_FRAMEWORK_ADMIN_ASSETS_ROOT.'/img/header-vertical.png'
					)
				),
				'args' => array(
					'use_images' => true,
					'hide_labels' => true,
					'dependence' => true,
					'show' => array(
						'header-standard' => '#eltdf_panel_header_standard,#eltdf_header_behaviour,#eltdf_panel_fixed_header,#eltdf_panel_sticky_header,#eltdf_panel_main_menu',
						'header-full-screen' => '#eltdf_panel_header_full_screen',
						'header-vertical' => '#eltdf_panel_header_vertical,#eltdf_panel_vertical_main_menu'
					),
					'hide' => array(
						'header-standard' => '#eltdf_panel_header_full_screen,#eltdf_panel_header_vertical,#eltdf_panel_vertical_main_menu',
						'header-full-screen' => '#eltdf_panel_header_standard,#eltdf_panel_header_vertical,#eltdf_panel_vertical_main_menu,#eltdf_panel_main_menu,#eltdf_header_behaviour,#eltdf_panel_fixed_header,#eltdf_panel_sticky_header',
						'header-vertical' => '#eltdf_panel_header_standard,#eltdf_panel_header_full_screen,#eltdf_header_behaviour,#eltdf_panel_fixed_header,#eltdf_panel_sticky_header,#eltdf_panel_main_menu'
					)
				)
			)
		);

		blu_elated_add_admin_field(
			array(
				'parent' => $panel_header,
				'type' => 'select',
				'name' => 'header_behaviour',
				'default_value' => 'fixed-on-scroll',
				'label' => esc_html__('Choose Header Behaviour', 'blu'),
				'description' => esc_html__('Select the behaviour of header when you scroll down to page', 'blu'),
				'options' => array(
					'sticky-header-on-scroll-up' => esc_html__('Sticky on scroll up', 'blu'),
					'sticky-header-on-scroll-down-up' => esc_html__('Sticky on scroll up/down', 'blu'),
					'fixed-on-scroll' => esc_html__('Fixed on scroll', 'blu')
				),
				'args' => array(
					'dependence' => true,
					'show' => array(
						'sticky-header-on-scroll-up' => '#eltdf_panel_sticky_header',
						'sticky-header-on-scroll-down-up' => '#eltdf_panel_sticky_header',
						'fixed-on-scroll' => '#eltdf_panel_fixed_header'
					),
					'hide' => array(
						'sticky-header-on-scroll-up' => '#eltdf_panel_fixed_header',
						'sticky-header-on-scroll-down-up' => '#eltdf_panel_fixed_header',
						'fixed-on-scroll' => '#eltdf_panel_sticky_header'
					)
				),
                'hidden_property' => 'header_type',
                'hidden_value' => '',
                'hidden_values' => array(
	                'header-full-screen',
	                'header-vertical'
                )
			)
		);

		/***************** Top Header Layout **********************/

			blu_elated_add_admin_field(
				array(
					'name' => 'top_bar',
					'type' => 'yesno',
					'default_value' => 'no',
					'label' => esc_html__('Top Bar', 'blu'),
					'description' => esc_html__('Enabling this option will show top bar area', 'blu'),
					'parent' => $panel_header,
					'args' => array(
						"dependence" => true,
						"dependence_hide_on_yes" => "",
						"dependence_show_on_yes" => "#eltdf_top_bar_container"
					)
				)
			);

			$top_bar_container = blu_elated_add_admin_container(array(
				'name' => 'top_bar_container',
				'parent' => $panel_header,
				'hidden_property' => 'top_bar',
				'hidden_value' => 'no'
			));
		
			blu_elated_add_admin_field(
				array(
					'name' => 'top_bar_in_grid',
					'type' => 'yesno',
					'default_value' => 'no',
					'label' => esc_html__('Top Bar in Grid', 'blu'),
					'description' => esc_html__('Set top bar content to be in grid', 'blu'),
					'parent' => $top_bar_container
				)
			);

			blu_elated_add_admin_field(array(
				'name' => 'top_bar_background_color',
				'type' => 'color',
				'label' => esc_html__('Background Color', 'blu'),
				'description' => esc_html__('Choose a background color for header area', 'blu'),
				'parent' => $top_bar_container
			));

			blu_elated_add_admin_field(array(
				'name' => 'top_bar_background_transparency',
				'type' => 'text',
				'label' => esc_html__('Background Transparency', 'blu'),
				'description' => esc_html__('Choose a transparency for the header background color (0 = fully transparent, 1 = opaque)', 'blu'),
				'parent' => $top_bar_container,
				'args' => array('col_width' => 3)
			));

			blu_elated_add_admin_field(array(
				'name' => 'top_bar_height',
				'type' => 'text',
				'label' => esc_html__('Top Bar Height', 'blu'),
				'description' => esc_html__('Enter top bar height (Default is 30px)', 'blu'),
				'parent' => $top_bar_container,
				'args' => array(
					'col_width' => 2,
					'suffix' => 'px'
				)
			));

		/***************** Top Header Layout **********************/	

		/***************** Header Skin Options ********************/

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_header,
					'type' => 'select',
					'name' => 'header_style',
					'default_value' => '',
					'label' => esc_html__('Header Skin', 'blu'),
					'description' => esc_html__('Choose a header style to make header elements (logo, main menu, side menu button) in that predefined style', 'blu'),
					'options' => array(
						'' => esc_html__('Default', 'blu'),
						'light-header' => esc_html__('Light', 'blu'),
						'dark-header' => esc_html__('Dark', 'blu')
					)
				)
			);

		/***************** Header Skin Options ********************/	

		/***************** Standard Header Layout *****************/

			$panel_header_standard = blu_elated_add_admin_panel(
				array(
					'page' => '_header_page',
					'name' => 'panel_header_standard',
					'title' => esc_html__('Header Standard', 'blu'),
					'hidden_property' => 'header_type',
					'hidden_value' => '',
					'hidden_values' => array(
	                    'header-full-screen',
						'header-vertical'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_header_standard,
					'type' => 'yesno',
					'name' => 'enable_grid_layout_header',
					'default_value' => 'no',
					'label' => esc_html__('Enable Grid Layout', 'blu'),
					'description' => esc_html__('Enabling this option you will set standard header area to be in grid and menu will be on the right side', 'blu'),
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_header_standard,
					'type' => 'select',
					'name' => 'set_menu_area_position',
					'default_value' => 'center',
					'label' => esc_html__('Choose Menu Area Position', 'blu'),
					'description' => esc_html__('Select menu area position in your header', 'blu'),
					'options' => array(
						'center' => esc_html__('Center', 'blu'),
						'right' => esc_html__('Right', 'blu')
					)
				)
			);

			blu_elated_add_admin_section_title(
				array(
					'parent' => $panel_header_standard,
					'name' => 'menu_area_title',
					'title' => esc_html__('Menu Area', 'blu')
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_header_standard,
					'type' => 'color',
					'name' => 'menu_area_background_color_header_standard',
					'default_value' => '',
					'label' => esc_html__('Background Color', 'blu'),
					'description' => esc_html__('Choose a background color for header area', 'blu'),
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_header_standard,
					'type' => 'text',
					'name' => 'menu_area_background_transparency_header_standard',
					'default_value' => '',
					'label' => esc_html__('Background Transparency', 'blu'),
					'description' => esc_html__('Choose a transparency for the header background color (0 = fully transparent, 1 = opaque)', 'blu'),
					'args' => array(
						'col_width' => 3
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_header_standard,
					'type' => 'color',
					'name' => 'menu_area_border_color_header_standard',
					'default_value' => '',
					'label' => esc_html__('Border Color', 'blu'),
					'description' => esc_html__('Set border color for header', 'blu')
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_header_standard,
					'type' => 'text',
					'name' => 'menu_area_height_header_standard',
					'default_value' => '',
					'label' => esc_html__('Height', 'blu'),
					'description' => esc_html__('Enter Header Height (default is 80px)', 'blu'),
					'args' => array(
						'col_width' => 3,
						'suffix' => 'px'
					)
				)
			);

		/***************** Standard Header Layout *****************/

		/***************** Full Screen Header Layout *******************/

			$panel_header_full_screen = blu_elated_add_admin_panel(
				array(
					'page' => '_header_page',
					'name' => 'panel_header_full_screen',
					'title' => esc_html__('Header Full Screen', 'blu'),
					'hidden_property' => 'header_type',
					'hidden_value' => '',
					'hidden_values' => array(
	                    'header-standard',
						'header-vertical'
					)
				)
			);

			blu_elated_add_admin_section_title(
				array(
					'parent' => $panel_header_full_screen,
					'name' => 'header_full_screen_title',
					'title' => esc_html__('Header Full Screen', 'blu')
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_header_full_screen,
					'type' => 'yesno',
					'name' => 'enable_grid_layout_header_full_screen',
					'default_value' => 'yes',
					'label' => esc_html__('Enable Grid Layout', 'blu'),
					'description' => esc_html__('Enabling this option you will set full screen header area to be in grid', 'blu'),
				)
			);

			blu_elated_add_admin_section_title(
				array(
					'parent' => $panel_header_full_screen,
					'name' => 'menu_area_title',
					'title' => esc_html__('Menu Area', 'blu')
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_header_full_screen,
					'type' => 'color',
					'name' => 'menu_area_background_color_header_full_screen',
					'default_value' => '',
					'label' => esc_html__('Background Color', 'blu'),
					'description' => esc_html__('Choose a background color for header area', 'blu'),
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_header_full_screen,
					'type' => 'text',
					'name' => 'menu_area_background_transparency_header_full_screen',
					'default_value' => '',
					'label' => esc_html__('Background Transparency', 'blu'),
					'description' => esc_html__('Choose a transparency for the header background color (0 = fully transparent, 1 = opaque)', 'blu'),
					'args' => array(
						'col_width' => 3
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_header_full_screen,
					'type' => 'color',
					'name' => 'menu_area_border_color_header_full_screen',
					'default_value' => '',
					'label' => esc_html__('Border Color', 'blu'),
					'description' => esc_html__('Set border color for header', 'blu')
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_header_full_screen,
					'type' => 'text',
					'name' => 'menu_area_height_header_full_screen',
					'default_value' => '',
					'label' => esc_html__('Height', 'blu'),
					'description' => esc_html__('Enter Header Height (default is 80px)', 'blu'),
					'args' => array(
						'col_width' => 3,
						'suffix' => 'px'
					)
				)
			);

		/***************** Full Screen Header Layout *******************/

		/***************** Vertical Header Layout *****************/

			$panel_header_vertical = blu_elated_add_admin_panel(
				array(
					'page' => '_header_page',
					'name' => 'panel_header_vertical',
					'title' => esc_html__('Header Vertical', 'blu'),
					'hidden_property' => 'header_type',
					'hidden_value' => '',
					'hidden_values' => array(
						'header-standard',
						'header-full-screen'
					)
				)
			);

			blu_elated_add_admin_field(array(
				'name' => 'vertical_header_background_color',
				'type' => 'color',
				'label' => esc_html__('Background Color', 'blu'),
				'description' => esc_html__('Choose a background color for header area', 'blu'),
				'parent' => $panel_header_vertical
			));

			blu_elated_add_admin_field(array(
				'name' => 'vertical_header_transparency',
				'type' => 'text',
				'label' => esc_html__('Background Transparency', 'blu'),
				'description' => esc_html__('Choose a transparency for the header background color (0 = fully transparent, 1 = opaque)', 'blu'),
				'parent' => $panel_header_vertical,
				'args' => array(
					'col_width' => 1
				)
			));

			blu_elated_add_admin_field(
				array(
					'name' => 'vertical_header_background_image',
					'type' => 'image',
					'label' => esc_html__('Background Image', 'blu'),
					'description' => esc_html__('Set background image for vertical menu', 'blu'),
					'parent' => $panel_header_vertical
				)
			);

			blu_elated_add_admin_field(
				array(
					'name' => 'vertical_header_text_align',
					'type' => 'select',
					'default_value' => '',
					'label' => esc_html__('Choose Text Alignment', 'blu'),
					'description' => esc_html__('Choose text alignment for Vertical Header elements (logo, menu and widgets)', 'blu'),
					'parent' => $panel_header_vertical,
					'options' => array(
						'' => esc_html__('Default', 'blu'),
						'left' => esc_html__('Left', 'blu'),
						'center' => esc_html__('Center', 'blu')
					)
				)
			);

		/***************** Vertical Header Layout *****************/

        /***************** Sticky Header Layout *******************/

			$panel_sticky_header = blu_elated_add_admin_panel(
				array(
					'title' => esc_html__('Sticky Header', 'blu'),
					'name' => 'panel_sticky_header',
					'page' => '_header_page',
					'hidden_property' => 'header_type',
					'hidden_value' => '',
					'hidden_values' => array(
	                    'header-full-screen',
						'header-vertical'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'name' => 'scroll_amount_for_sticky',
					'type' => 'text',
					'label' => esc_html__('Scroll Amount for Sticky', 'blu'),
					'description' => esc_html__('Enter scroll amount for Sticky Menu to appear (deafult is header height). This value can be overriden on a page level basis', 'blu'),
					'parent' => $panel_sticky_header,
					'args' => array(
						'col_width' => 2,
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'name' => 'sticky_header_in_grid',
					'type' => 'yesno',
					'default_value' => 'no',
					'label' => esc_html__('Sticky Header in Grid', 'blu'),
					'description' => esc_html__('Enabling this option will put sticky header in grid', 'blu'),
					'parent' => $panel_sticky_header,
				)
			);

			blu_elated_add_admin_field(array(
				'name' => 'sticky_header_background_color',
				'type' => 'color',
				'label' => esc_html__('Background Color', 'blu'),
				'description' => esc_html__('Choose a background color for header area', 'blu'),
				'parent' => $panel_sticky_header
			));

			blu_elated_add_admin_field(array(
				'name' => 'sticky_header_transparency',
				'type' => 'text',
				'label' => esc_html__('Background Transparency', 'blu'),
				'description' => esc_html__('Choose a transparency for the header background color (0 = fully transparent, 1 = opaque)', 'blu'),
				'parent' => $panel_sticky_header,
				'args' => array(
					'col_width' => 1
				)
			));

			blu_elated_add_admin_field(array(
				'name' => 'sticky_header_border_color',
				'type' => 'color',
				'label' => esc_html__('Border Color', 'blu'),
				'description' => esc_html__('Set border bottom color for header area', 'blu'),
				'parent' => $panel_sticky_header
			));

			blu_elated_add_admin_field(array(
				'name' => 'sticky_header_height',
				'type' => 'text',
				'label' => esc_html__('Sticky Header Height', 'blu'),
				'description' => esc_html__('Enter height for sticky header (default is 60px)', 'blu'),
				'parent' => $panel_sticky_header,
				'args' => array(
					'col_width' => 2,
					'suffix' => 'px'
				)
			));

			$group_sticky_header_menu = blu_elated_add_admin_group(array(
				'title' => esc_html__('Sticky Header Menu', 'blu'),
				'name' => 'group_sticky_header_menu',
				'parent' => $panel_sticky_header,
				'description' => esc_html__('Define styles for sticky menu items', 'blu')
			));

			$row1_sticky_header_menu = blu_elated_add_admin_row(array(
				'name' => 'row1',
				'parent' => $group_sticky_header_menu
			));

			blu_elated_add_admin_field(array(
				'name' => 'sticky_color',
				'type' => 'colorsimple',
				'label' => esc_html__('Text Color', 'blu'),
				'description' => '',
				'parent' => $row1_sticky_header_menu
			));

			blu_elated_add_admin_field(array(
				'name' => 'sticky_hovercolor',
				'type' => 'colorsimple',
				'label' => esc_html__(esc_html__('Hover/Active Color', 'blu'), 'blu'),
				'description' => '',
				'parent' => $row1_sticky_header_menu
			));

			$row2_sticky_header_menu = blu_elated_add_admin_row(array(
				'name' => 'row2',
				'parent' => $group_sticky_header_menu
			));

			blu_elated_add_admin_field(
				array(
					'name' => 'sticky_google_fonts',
					'type' => 'fontsimple',
					'label' => esc_html__('Font Family', 'blu'),
					'default_value' => '-1',
					'parent' => $row2_sticky_header_menu,
				)
			);

			blu_elated_add_admin_field(
				array(
					'type' => 'textsimple',
					'name' => 'sticky_fontsize',
					'label' => esc_html__('Font Size', 'blu'),
					'default_value' => '',
					'parent' => $row2_sticky_header_menu,
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'type' => 'textsimple',
					'name' => 'sticky_lineheight',
					'label' => esc_html__('Line Height', 'blu'),
					'default_value' => '',
					'parent' => $row2_sticky_header_menu,
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'type' => 'selectblanksimple',
					'name' => 'sticky_texttransform',
					'label' => esc_html__('Text Transform', 'blu'),
					'default_value' => '',
					'options' => blu_elated_get_text_transform_array(),
					'parent' => $row2_sticky_header_menu
				)
			);

			$row3_sticky_header_menu = blu_elated_add_admin_row(array(
				'name' => 'row3',
				'parent' => $group_sticky_header_menu
			));

			blu_elated_add_admin_field(
				array(
					'type' => 'selectblanksimple',
					'name' => 'sticky_fontstyle',
					'default_value' => '',
					'label' => esc_html__('Font Style', 'blu'),
					'options' => blu_elated_get_font_style_array(),
					'parent' => $row3_sticky_header_menu
				)
			);

			blu_elated_add_admin_field(
				array(
					'type' => 'selectblanksimple',
					'name' => 'sticky_fontweight',
					'default_value' => '',
					'label' => esc_html__('Font Weight', 'blu'),
					'options' => blu_elated_get_font_weight_array(),
					'parent' => $row3_sticky_header_menu
				)
			);

			blu_elated_add_admin_field(
				array(
					'type' => 'textsimple',
					'name' => 'sticky_letterspacing',
					'label' => esc_html__('Letter Spacing', 'blu'),
					'default_value' => '',
					'parent' => $row3_sticky_header_menu,
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

		/***************** Sticky Header Layout *******************/	

		/***************** Fixed Header Layout ********************/	

			$panel_fixed_header = blu_elated_add_admin_panel(
				array(
					'title' => esc_html__('Fixed Header', 'blu'),
					'name' => 'panel_fixed_header',
					'page' => '_header_page',
					'hidden_property' => 'header_type',
					'hidden_value' => '',
					'hidden_values' => array(
	                    'header-full-screen',
						'header-vertical'
					)
				)
			);

			blu_elated_add_admin_field(array(
				'name' => 'fixed_header_background_color',
				'type' => 'color',
				'default_value' => '',
				'label' => esc_html__('Background Color', 'blu'),
				'description' => esc_html__('Choose a background color for header area', 'blu'),
				'parent' => $panel_fixed_header
			));

			blu_elated_add_admin_field(array(
				'name' => 'fixed_header_transparency',
				'type' => 'text',
				'label' => esc_html__('Background Transparency', 'blu'),
				'description' => esc_html__('Choose a transparency for the header background color (0 = fully transparent, 1 = opaque)', 'blu'),
				'parent' => $panel_fixed_header,
				'args' => array(
					'col_width' => 1
				)
			));

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_fixed_header,
					'type' => 'color',
					'name' => 'fixed_header_border_bottom_color',
					'default_value' => '',
					'label' => esc_html__('Border Color', 'blu'),
					'description' => esc_html__('Set border bottom color for header area', 'blu'),
				)
			);

			$group_fixed_header_menu = blu_elated_add_admin_group(array(
				'title' => esc_html__('Fixed Header Menu', 'blu'),
				'name' => 'group_fixed_header_menu',
				'parent' => $panel_fixed_header,
				'description' => esc_html__('Define styles for fixed menu items', 'blu')
			));

			$row1_fixed_header_menu = blu_elated_add_admin_row(array(
				'name' => 'row1',
				'parent' => $group_fixed_header_menu
			));

			blu_elated_add_admin_field(array(
				'name' => 'fixed_color',
				'type' => 'colorsimple',
				'label' => esc_html__('Text Color', 'blu'),
				'description' => '',
				'parent' => $row1_fixed_header_menu
			));

			blu_elated_add_admin_field(array(
				'name' => 'fixed_hovercolor',
				'type' => 'colorsimple',
				'label' => esc_html__(esc_html__('Hover/Active Color', 'blu'), 'blu'),
				'description' => '',
				'parent' => $row1_fixed_header_menu
			));

			$row2_fixed_header_menu = blu_elated_add_admin_row(array(
				'name' => 'row2',
				'parent' => $group_fixed_header_menu
			));

			blu_elated_add_admin_field(
				array(
					'name' => 'fixed_google_fonts',
					'type' => 'fontsimple',
					'label' => esc_html__('Font Family', 'blu'),
					'default_value' => '-1',
					'parent' => $row2_fixed_header_menu,
				)
			);

			blu_elated_add_admin_field(
				array(
					'type' => 'textsimple',
					'name' => 'fixed_fontsize',
					'label' => esc_html__('Font Size', 'blu'),
					'default_value' => '',
					'parent' => $row2_fixed_header_menu,
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'type' => 'textsimple',
					'name' => 'fixed_lineheight',
					'label' => esc_html__('Line Height', 'blu'),
					'default_value' => '',
					'parent' => $row2_fixed_header_menu,
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'type' => 'selectblanksimple',
					'name' => 'fixed_texttransform',
					'label' => esc_html__('Text Transform', 'blu'),
					'default_value' => '',
					'options' => blu_elated_get_text_transform_array(),
					'parent' => $row2_fixed_header_menu
				)
			);

			$row3_fixed_header_menu = blu_elated_add_admin_row(array(
				'name' => 'row3',
				'parent' => $group_fixed_header_menu
			));

			blu_elated_add_admin_field(
				array(
					'type' => 'selectblanksimple',
					'name' => 'fixed_fontstyle',
					'default_value' => '',
					'label' => esc_html__('Font Style', 'blu'),
					'options' => blu_elated_get_font_style_array(),
					'parent' => $row3_fixed_header_menu
				)
			);

			blu_elated_add_admin_field(
				array(
					'type' => 'selectblanksimple',
					'name' => 'fixed_fontweight',
					'default_value' => '',
					'label' => esc_html__('Font Weight', 'blu'),
					'options' => blu_elated_get_font_weight_array(),
					'parent' => $row3_fixed_header_menu
				)
			);

			blu_elated_add_admin_field(
				array(
					'type' => 'textsimple',
					'name' => 'fixed_letterspacing',
					'label' => esc_html__('Letter Spacing', 'blu'),
					'default_value' => '',
					'parent' => $row3_fixed_header_menu,
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

		/***************** Fixed Header Layout ********************/	

		/******************* Main Menu Layout *********************/

			$panel_main_menu = blu_elated_add_admin_panel(
				array(
					'title' => esc_html__('Main Menu', 'blu'),
					'name' => 'panel_main_menu',
					'page' => '_header_page',
					'hidden_property' => 'header_type',
	                'hidden_values' => array(
	                	'header-full-screen',
		                'header-vertical'
	            	)
				)
			);

			blu_elated_add_admin_section_title(
				array(
					'parent' => $panel_main_menu,
					'name' => 'main_menu_area_title',
					'title' => esc_html__('Main Menu General Settings', 'blu')
				)
			);

			$drop_down_group = blu_elated_add_admin_group(
				array(
					'parent' => $panel_main_menu,
					'name' => 'drop_down_group',
					'title' => esc_html__('Main Dropdown Menu', 'blu'),
					'description' => esc_html__('Choose a color and transparency for the main menu background (0 = fully transparent, 1 = opaque)', 'blu')
				)
			);

			$drop_down_row1 = blu_elated_add_admin_row(
				array(
					'parent' => $drop_down_group,
					'name' => 'drop_down_row1',
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $drop_down_row1,
					'type' => 'colorsimple',
					'name' => 'dropdown_background_color',
					'default_value' => '',
					'label' => esc_html__('Background Color', 'blu'),
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $drop_down_row1,
					'type' => 'textsimple',
					'name' => 'dropdown_background_transparency',
					'default_value' => '',
					'label' => esc_html__('Background Transparency', 'blu'),
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_main_menu,
					'type' => 'select',
					'name' => 'menu_dropdown_appearance',
					'default_value' => 'dropdown-animate-height',
					'label' => esc_html__('Main Dropdown Menu Appearance', 'blu'),
					'description' => esc_html__('Choose appearance for dropdown menu', 'blu'),
					'options' => array(
						'dropdown-default' => esc_html__('Default', 'blu'),
						'dropdown-animate-height' => esc_html__('Animate Height', 'blu'),
						'dropdown-slide-from-bottom' => esc_html__('Slide From Bottom','blu'),
						'dropdown-slide-from-top' =>esc_html__( 'Slide From Top','blu'),
						'dropdown-slide-from-left' =>esc_html__( 'Slide From Left','blu')
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $panel_main_menu,
					'type' => 'text',
					'name' => 'dropdown_top_position',
					'default_value' => '',
					'label' => esc_html__('Dropdown Position', 'blu'),
					'description' => esc_html__('Enter value in percentage of entire header height', 'blu'),
					'args' => array(
						'col_width' => 3,
						'suffix' => '%'
					)
				)
			);

			$first_level_group = blu_elated_add_admin_group(
				array(
					'parent' => $panel_main_menu,
					'name' => 'first_level_group',
					'title' => esc_html__('1st Level Menu', 'blu'),
					'description' => esc_html__('Define styles for 1st level in Top Navigation Menu', 'blu')
				)
			);

			$first_level_row1 = blu_elated_add_admin_row(
				array(
					'parent' => $first_level_group,
					'name' => 'first_level_row1'
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row1,
					'type' => 'colorsimple',
					'name' => 'menu_color',
					'default_value' => '',
					'label' => esc_html__('Text Color', 'blu'),
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row1,
					'type' => 'colorsimple',
					'name' => 'menu_hovercolor',
					'default_value' => '',
					'label' => esc_html__('Hover Text Color', 'blu'),
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row1,
					'type' => 'colorsimple',
					'name' => 'menu_activecolor',
					'default_value' => '',
					'label' => esc_html__('Active Text Color', 'blu'),
				)
			);

			$first_level_row3 = blu_elated_add_admin_row(
				array(
					'parent' => $first_level_group,
					'name' => 'first_level_row3',
					'next' => true
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row3,
					'type' => 'colorsimple',
					'name' => 'menu_light_hovercolor',
					'default_value' => '',
					'label' => esc_html__('Light Menu Hover Text Color', 'blu'),
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row3,
					'type' => 'colorsimple',
					'name' => 'menu_light_activecolor',
					'default_value' => '',
					'label' => esc_html__('Light Menu Active Text Color', 'blu'),
				)
			);

			$first_level_row4 = blu_elated_add_admin_row(
				array(
					'parent' => $first_level_group,
					'name' => 'first_level_row4',
					'next' => true
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row4,
					'type' => 'colorsimple',
					'name' => 'menu_dark_hovercolor',
					'default_value' => '',
					'label' => esc_html__('Dark Menu Hover Text Color', 'blu'),
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row4,
					'type' => 'colorsimple',
					'name' => 'menu_dark_activecolor',
					'default_value' => '',
					'label' => esc_html__('Dark Menu Active Text Color', 'blu'),
				)
			);

			$first_level_row5 = blu_elated_add_admin_row(
				array(
					'parent' => $first_level_group,
					'name' => 'first_level_row5',
					'next' => true
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row5,
					'type' => 'fontsimple',
					'name' => 'menu_google_fonts',
					'default_value' => '-1',
					'label' => esc_html__('Font Family', 'blu'),
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row5,
					'type' => 'textsimple',
					'name' => 'menu_fontsize',
					'default_value' => '',
					'label' => esc_html__('Font Size', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row5,
					'type' => 'textsimple',
					'name' => 'menu_lineheight',
					'default_value' => '',
					'label' => esc_html__('Line Height', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			$first_level_row6 = blu_elated_add_admin_row(
				array(
					'parent' => $first_level_group,
					'name' => 'first_level_row6',
					'next' => true
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row6,
					'type' => 'selectblanksimple',
					'name' => 'menu_fontstyle',
					'default_value' => '',
					'label' => esc_html__('Font Style', 'blu'),
					'options' => blu_elated_get_font_style_array()
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row6,
					'type' => 'selectblanksimple',
					'name' => 'menu_fontweight',
					'default_value' => '',
					'label' => esc_html__('Font Weight', 'blu'),
					'options' => blu_elated_get_font_weight_array()
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row6,
					'type' => 'textsimple',
					'name' => 'menu_letterspacing',
					'default_value' => '',
					'label' => esc_html__('Letter Spacing', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row6,
					'type' => 'selectblanksimple',
					'name' => 'menu_texttransform',
					'default_value' => '',
					'label' => esc_html__('Text Transform', 'blu'),
					'options' => blu_elated_get_text_transform_array()
				)
			);

			$first_level_row7 = blu_elated_add_admin_row(
				array(
					'parent' => $first_level_group,
					'name' => 'first_level_row7',
					'next' => true
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row7,
					'type' => 'textsimple',
					'name' => 'menu_padding_left_right',
					'default_value' => '',
					'label' => esc_html__('Padding Left/Right', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $first_level_row7,
					'type' => 'textsimple',
					'name' => 'menu_margin_left_right',
					'default_value' => '',
					'label' => esc_html__('Margin Left/Right', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			$second_level_group = blu_elated_add_admin_group(
				array(
					'parent' => $panel_main_menu,
					'name' => 'second_level_group',
					'title' => esc_html__('2nd Level Menu', 'blu'),
					'description' => esc_html__('Define styles for 2nd level in Top Navigation Menu', 'blu')
				)
			);

			$second_level_row1 = blu_elated_add_admin_row(
				array(
					'parent' => $second_level_group,
					'name' => 'second_level_row1'
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_row1,
					'type' => 'colorsimple',
					'name' => 'dropdown_color',
					'default_value' => '',
					'label' => esc_html__('Text Color', 'blu')
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_row1,
					'type' => 'colorsimple',
					'name' => 'dropdown_hovercolor',
					'default_value' => '',
					'label' => esc_html__('Hover/Active Color', 'blu')
				)
			);

			$second_level_row2 = blu_elated_add_admin_row(
				array(
					'parent' => $second_level_group,
					'name' => 'second_level_row2',
					'next' => true
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_row2,
					'type' => 'fontsimple',
					'name' => 'dropdown_google_fonts',
					'default_value' => '-1',
					'label' => esc_html__('Font Family', 'blu')
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_row2,
					'type' => 'textsimple',
					'name' => 'dropdown_fontsize',
					'default_value' => '',
					'label' => esc_html__('Font Size', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_row2,
					'type' => 'textsimple',
					'name' => 'dropdown_lineheight',
					'default_value' => '',
					'label' => esc_html__('Line Height', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			$second_level_row3 = blu_elated_add_admin_row(
				array(
					'parent' => $second_level_group,
					'name' => 'second_level_row3',
					'next' => true
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_row3,
					'type' => 'selectblanksimple',
					'name' => 'dropdown_fontstyle',
					'default_value' => '',
					'label' => esc_html__('Font Style', 'blu'),
					'options' => blu_elated_get_font_style_array()
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_row3,
					'type' => 'selectblanksimple',
					'name' => 'dropdown_fontweight',
					'default_value' => '',
					'label' => esc_html__('Font Weight', 'blu'),
					'options' => blu_elated_get_font_weight_array()
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_row3,
					'type' => 'textsimple',
					'name' => 'dropdown_letterspacing',
					'default_value' => '',
					'label' => esc_html__('Letter Spacing', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_row3,
					'type' => 'selectblanksimple',
					'name' => 'dropdown_texttransform',
					'default_value' => '',
					'label' => esc_html__('Text Transform', 'blu'),
					'options' => blu_elated_get_text_transform_array()
				)
			);

			$second_level_wide_group = blu_elated_add_admin_group(
				array(
					'parent' => $panel_main_menu,
					'name' => 'second_level_wide_group',
					'title' => esc_html__('2nd Level Wide Menu', 'blu'),
					'description' => esc_html__('Define styles for 2nd level in Wide Menu', 'blu')
				)
			);

			$second_level_wide_row1 = blu_elated_add_admin_row(
				array(
					'parent' => $second_level_wide_group,
					'name' => 'second_level_wide_row1'
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_wide_row1,
					'type' => 'colorsimple',
					'name' => 'dropdown_wide_color',
					'default_value' => '',
					'label' => esc_html__('Text Color', 'blu')
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_wide_row1,
					'type' => 'colorsimple',
					'name' => 'dropdown_wide_hovercolor',
					'default_value' => '',
					'label' => esc_html__('Hover/Active Color', 'blu')
				)
			);

			$second_level_wide_row2 = blu_elated_add_admin_row(
				array(
					'parent' => $second_level_wide_group,
					'name' => 'second_level_wide_row2',
					'next' => true
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_wide_row2,
					'type' => 'fontsimple',
					'name' => 'dropdown_wide_google_fonts',
					'default_value' => '-1',
					'label' => esc_html__('Font Family', 'blu')
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_wide_row2,
					'type' => 'textsimple',
					'name' => 'dropdown_wide_fontsize',
					'default_value' => '',
					'label' => esc_html__('Font Size', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_wide_row2,
					'type' => 'textsimple',
					'name' => 'dropdown_wide_lineheight',
					'default_value' => '',
					'label' => esc_html__('Line Height', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			$second_level_wide_row3 = blu_elated_add_admin_row(
				array(
					'parent' => $second_level_wide_group,
					'name' => 'second_level_wide_row3',
					'next' => true
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_wide_row3,
					'type' => 'selectblanksimple',
					'name' => 'dropdown_wide_fontstyle',
					'default_value' => '',
					'label' => esc_html__('Font Style', 'blu'),
					'options' => blu_elated_get_font_style_array()
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_wide_row3,
					'type' => 'selectblanksimple',
					'name' => 'dropdown_wide_fontweight',
					'default_value' => '',
					'label' => esc_html__('Font Weight', 'blu'),
					'options' => blu_elated_get_font_weight_array()
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_wide_row3,
					'type' => 'textsimple',
					'name' => 'dropdown_wide_letterspacing',
					'default_value' => '',
					'label' => esc_html__('Letter Spacing', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $second_level_wide_row3,
					'type' => 'selectblanksimple',
					'name' => 'dropdown_wide_texttransform',
					'default_value' => '',
					'label' => esc_html__('Text Transform', 'blu'),
					'options' => blu_elated_get_text_transform_array()
				)
			);

			$third_level_group = blu_elated_add_admin_group(
				array(
					'parent' => $panel_main_menu,
					'name' => 'third_level_group',
					'title' => esc_html__('3nd Level Menu', 'blu'),
					'description' => esc_html__('Define styles for 3nd level in Top Navigation Menu', 'blu')
				)
			);

			$third_level_row1 = blu_elated_add_admin_row(
				array(
					'parent' => $third_level_group,
					'name' => 'third_level_row1'
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_row1,
					'type' => 'colorsimple',
					'name' => 'dropdown_color_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Text Color', 'blu')
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_row1,
					'type' => 'colorsimple',
					'name' => 'dropdown_hovercolor_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Hover/Active Color', 'blu')
				)
			);

			$third_level_row2 = blu_elated_add_admin_row(
				array(
					'parent' => $third_level_group,
					'name' => 'third_level_row2',
					'next' => true
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_row2,
					'type' => 'fontsimple',
					'name' => 'dropdown_google_fonts_thirdlvl',
					'default_value' => '-1',
					'label' => esc_html__('Font Family', 'blu')
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_row2,
					'type' => 'textsimple',
					'name' => 'dropdown_fontsize_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Font Size', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_row2,
					'type' => 'textsimple',
					'name' => 'dropdown_lineheight_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Line Height', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			$third_level_row3 = blu_elated_add_admin_row(
				array(
					'parent' => $third_level_group,
					'name' => 'third_level_row3',
					'next' => true
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_row3,
					'type' => 'selectblanksimple',
					'name' => 'dropdown_fontstyle_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Font Style', 'blu'),
					'options' => blu_elated_get_font_style_array()
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_row3,
					'type' => 'selectblanksimple',
					'name' => 'dropdown_fontweight_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Font Weight', 'blu'),
					'options' => blu_elated_get_font_weight_array()
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_row3,
					'type' => 'textsimple',
					'name' => 'dropdown_letterspacing_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Letter Spacing', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_row3,
					'type' => 'selectblanksimple',
					'name' => 'dropdown_texttransform_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Text Transform', 'blu'),
					'options' => blu_elated_get_text_transform_array()
				)
			);

			$third_level_wide_group = blu_elated_add_admin_group(
				array(
					'parent' => $panel_main_menu,
					'name' => 'third_level_wide_group',
					'title' => esc_html__('3rd Level Wide Menu', 'blu'),
					'description' => esc_html__('Define styles for 3rd level in Wide Menu', 'blu')
				)
			);

			$third_level_wide_row1 = blu_elated_add_admin_row(
				array(
					'parent' => $third_level_wide_group,
					'name' => 'third_level_wide_row1'
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_wide_row1,
					'type' => 'colorsimple',
					'name' => 'dropdown_wide_color_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Text Color', 'blu')
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_wide_row1,
					'type' => 'colorsimple',
					'name' => 'dropdown_wide_hovercolor_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Hover/Active Color', 'blu')
				)
			);

			$third_level_wide_row2 = blu_elated_add_admin_row(
				array(
					'parent' => $third_level_wide_group,
					'name' => 'third_level_wide_row2',
					'next' => true
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_wide_row2,
					'type' => 'fontsimple',
					'name' => 'dropdown_wide_google_fonts_thirdlvl',
					'default_value' => '-1',
					'label' => esc_html__('Font Family', 'blu')
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_wide_row2,
					'type' => 'textsimple',
					'name' => 'dropdown_wide_fontsize_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Font Size', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_wide_row2,
					'type' => 'textsimple',
					'name' => 'dropdown_wide_lineheight_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Line Height', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			$third_level_wide_row3 = blu_elated_add_admin_row(
				array(
					'parent' => $third_level_wide_group,
					'name' => 'third_level_wide_row3',
					'next' => true
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_wide_row3,
					'type' => 'selectblanksimple',
					'name' => 'dropdown_wide_fontstyle_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Font Style', 'blu'),
					'options' => blu_elated_get_font_style_array()
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_wide_row3,
					'type' => 'selectblanksimple',
					'name' => 'dropdown_wide_fontweight_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Font Weight', 'blu'),
					'options' => blu_elated_get_font_weight_array()
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_wide_row3,
					'type' => 'textsimple',
					'name' => 'dropdown_wide_letterspacing_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Letter Spacing', 'blu'),
					'args' => array(
						'suffix' => 'px'
					)
				)
			);

			blu_elated_add_admin_field(
				array(
					'parent' => $third_level_wide_row3,
					'type' => 'selectblanksimple',
					'name' => 'dropdown_wide_texttransform_thirdlvl',
					'default_value' => '',
					'label' => esc_html__('Text Transform', 'blu'),
					'options' => blu_elated_get_text_transform_array()
				)
			);

        /******************* Main Menu Layout *********************/

		/****************** Vertical Main Menu Layout ********************/

			$panel_vertical_main_menu = blu_elated_add_admin_panel(
				array(
					'title' => esc_html__('Vertical Main Menu', 'blu'),
					'name' => 'panel_vertical_main_menu',
					'page' => '_header_page',
					'hidden_property' => 'header_type',
					'hidden_values' => array(
						'header-standard',
						'header-full-screen'
					)
				)
			);

			$drop_down_group = blu_elated_add_admin_group(
				array(
					'parent' => $panel_vertical_main_menu,
					'name' => 'vertical_drop_down_group',
					'title' => esc_html__('Main Dropdown Menu', 'blu'),
					'description' => esc_html__('Set a style for dropdown menu', 'blu')
				)
			);

			$vertical_drop_down_row1 = blu_elated_add_admin_row(
				array(
					'parent' => $drop_down_group,
					'name' => 'eltdf_drop_down_row1',
				)
			);

			blu_elated_add_admin_field(array(
				'type'			=> 'textsimple',
				'name'			=> 'vertical_menu_top_margin',
				'default_value'	=> '',
				'label'			=> esc_html__('Top Margin', 'blu'),
				'args'			=> array(
					'suffix'	=> 'px'
				),
				'parent'		=> $vertical_drop_down_row1
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'textsimple',
				'name'			=> 'vertical_menu_bottom_margin',
				'default_value'	=> '',
				'label'			=> esc_html__('Bottom Margin', 'blu'),
				'args'			=> array(
					'suffix'	=> 'px'
				),
				'parent'		=> $vertical_drop_down_row1
			));

			$group_vertical_first_level = blu_elated_add_admin_group(array(
				'name'			=> 'group_vertical_first_level',
				'title'			=> esc_html__('1st level', 'blu'),
				'description'	=> esc_html__('Define styles for 1st level menu', 'blu'),
				'parent'		=> $panel_vertical_main_menu
			));

			$row_vertical_first_level_1 = blu_elated_add_admin_row(array(
				'name'		=> 'row_vertical_first_level_1',
				'parent'	=> $group_vertical_first_level
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'colorsimple',
				'name'			=> 'vertical_menu_1st_color',
				'default_value'	=> '',
				'label'			=> esc_html__('Text Color', 'blu'),
				'parent'		=> $row_vertical_first_level_1
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'colorsimple',
				'name'			=> 'vertical_menu_1st_hover_color',
				'default_value'	=> '',
				'label'			=> esc_html__('Hover/Active Color', 'blu'),
				'parent'		=> $row_vertical_first_level_1
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'textsimple',
				'name'			=> 'vertical_menu_1st_fontsize',
				'default_value'	=> '',
				'label'			=> esc_html__('Font Size', 'blu'),
				'args'			=> array(
					'suffix'	=> 'px'
				),
				'parent'		=> $row_vertical_first_level_1
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'textsimple',
				'name'			=> 'vertical_menu_1st_lineheight',
				'default_value'	=> '',
				'label'			=> esc_html__('Line Height', 'blu'),
				'args'			=> array(
					'suffix'	=> 'px'
				),
				'parent'		=> $row_vertical_first_level_1
			));

			$row_vertical_first_level_2 = blu_elated_add_admin_row(array(
				'name'		=> 'row_vertical_first_level_2',
				'parent'	=> $group_vertical_first_level,
				'next'		=> true
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'selectblanksimple',
				'name'			=> 'vertical_menu_1st_texttransform',
				'default_value'	=> '',
				'label'			=> esc_html__('Text Transform', 'blu'),
				'options'		=> blu_elated_get_text_transform_array(),
				'parent'		=> $row_vertical_first_level_2
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'fontsimple',
				'name'			=> 'vertical_menu_1st_google_fonts',
				'default_value'	=> '-1',
				'label'			=> esc_html__('Font Family', 'blu'),
				'parent'		=> $row_vertical_first_level_2
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'selectblanksimple',
				'name'			=> 'vertical_menu_1st_fontstyle',
				'default_value'	=> '',
				'label'			=> esc_html__('Font Style', 'blu'),
				'options'		=> blu_elated_get_font_style_array(),
				'parent'		=> $row_vertical_first_level_2
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'selectblanksimple',
				'name'			=> 'vertical_menu_1st_fontweight',
				'default_value'	=> '',
				'label'			=> esc_html__('Font Weight', 'blu'),
				'options'		=> blu_elated_get_font_weight_array(),
				'parent'		=> $row_vertical_first_level_2
			));

			$row_vertical_first_level_3 = blu_elated_add_admin_row(array(
				'name'		=> 'row_vertical_first_level_3',
				'parent'	=> $group_vertical_first_level,
				'next'		=> true
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'textsimple',
				'name'			=> 'vertical_menu_1st_letter_spacing',
				'default_value'	=> '',
				'label'			=> esc_html__('Letter Spacing', 'blu'),
				'args'			=> array(
					'suffix'	=> 'px'
				),
				'parent'		=> $row_vertical_first_level_3
			));

			$group_vertical_second_level = blu_elated_add_admin_group(array(
				'name'			=> 'group_vertical_second_level',
				'title'			=> esc_html__('2nd level', 'blu'),
				'description'	=> esc_html__('Define styles for 2nd level menu', 'blu'),
				'parent'		=> $panel_vertical_main_menu
			));

			$row_vertical_second_level_1 = blu_elated_add_admin_row(array(
				'name'		=> 'row_vertical_second_level_1',
				'parent'	=> $group_vertical_second_level
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'colorsimple',
				'name'			=> 'vertical_menu_2nd_color',
				'default_value'	=> '',
				'label'			=> esc_html__('Text Color', 'blu'),
				'parent'		=> $row_vertical_second_level_1
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'colorsimple',
				'name'			=> 'vertical_menu_2nd_hover_color',
				'default_value'	=> '',
				'label'			=> esc_html__('Hover/Active Color', 'blu'),
				'parent'		=> $row_vertical_second_level_1
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'textsimple',
				'name'			=> 'vertical_menu_2nd_fontsize',
				'default_value'	=> '',
				'label'			=> esc_html__('Font Size', 'blu'),
				'args'			=> array(
					'suffix'	=> 'px'
				),
				'parent'		=> $row_vertical_second_level_1
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'textsimple',
				'name'			=> 'vertical_menu_2nd_lineheight',
				'default_value'	=> '',
				'label'			=> esc_html__('Line Height', 'blu'),
				'args'			=> array(
					'suffix'	=> 'px'
				),
				'parent'		=> $row_vertical_second_level_1
			));

			$row_vertical_second_level_2 = blu_elated_add_admin_row(array(
				'name'		=> 'row_vertical_second_level_2',
				'parent'	=> $group_vertical_second_level,
				'next'		=> true
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'selectblanksimple',
				'name'			=> 'vertical_menu_2nd_texttransform',
				'default_value'	=> '',
				'label'			=> esc_html__('Text Transform', 'blu'),
				'options'		=> blu_elated_get_text_transform_array(),
				'parent'		=> $row_vertical_second_level_2
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'fontsimple',
				'name'			=> 'vertical_menu_2nd_google_fonts',
				'default_value'	=> '-1',
				'label'			=> esc_html__('Font Family', 'blu'),
				'parent'		=> $row_vertical_second_level_2
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'selectblanksimple',
				'name'			=> 'vertical_menu_2nd_fontstyle',
				'default_value'	=> '',
				'label'			=> esc_html__('Font Style', 'blu'),
				'options'		=> blu_elated_get_font_style_array(),
				'parent'		=> $row_vertical_second_level_2
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'selectblanksimple',
				'name'			=> 'vertical_menu_2nd_fontweight',
				'default_value'	=> '',
				'label'			=> esc_html__('Font Weight', 'blu'),
				'options'		=> blu_elated_get_font_weight_array(),
				'parent'		=> $row_vertical_second_level_2
			));

			$row_vertical_second_level_3 = blu_elated_add_admin_row(array(
				'name'		=> 'row_vertical_second_level_3',
				'parent'	=> $group_vertical_second_level,
				'next'		=> true
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'textsimple',
				'name'			=> 'vertical_menu_2nd_letter_spacing',
				'default_value'	=> '',
				'label'			=> esc_html__('Letter Spacing', 'blu'),
				'args'			=> array(
					'suffix'	=> 'px'
				),
				'parent'		=> $row_vertical_second_level_3
			));

			$group_vertical_third_level = blu_elated_add_admin_group(array(
				'name'			=> 'group_vertical_third_level',
				'title'			=> esc_html__('3rd level', 'blu'),
				'description'	=> esc_html__('Define styles for 3rd level menu', 'blu'),
				'parent'		=> $panel_vertical_main_menu
			));

			$row_vertical_third_level_1 = blu_elated_add_admin_row(array(
				'name'		=> 'row_vertical_third_level_1',
				'parent'	=> $group_vertical_third_level
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'colorsimple',
				'name'			=> 'vertical_menu_3rd_color',
				'default_value'	=> '',
				'label'			=> esc_html__('Text Color', 'blu'),
				'parent'		=> $row_vertical_third_level_1
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'colorsimple',
				'name'			=> 'vertical_menu_3rd_hover_color',
				'default_value'	=> '',
				'label'			=> esc_html__('Hover/Active Color', 'blu'),
				'parent'		=> $row_vertical_third_level_1
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'textsimple',
				'name'			=> 'vertical_menu_3rd_fontsize',
				'default_value'	=> '',
				'label'			=> esc_html__('Font Size', 'blu'),
				'args'			=> array(
					'suffix'	=> 'px'
				),
				'parent'		=> $row_vertical_third_level_1
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'textsimple',
				'name'			=> 'vertical_menu_3rd_lineheight',
				'default_value'	=> '',
				'label'			=> esc_html__('Line Height', 'blu'),
				'args'			=> array(
					'suffix'	=> 'px'
				),
				'parent'		=> $row_vertical_third_level_1
			));

			$row_vertical_third_level_2 = blu_elated_add_admin_row(array(
				'name'		=> 'row_vertical_third_level_2',
				'parent'	=> $group_vertical_third_level,
				'next'		=> true
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'selectblanksimple',
				'name'			=> 'vertical_menu_3rd_texttransform',
				'default_value'	=> '',
				'label'			=> esc_html__('Text Transform', 'blu'),
				'options'		=> blu_elated_get_text_transform_array(),
				'parent'		=> $row_vertical_third_level_2
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'fontsimple',
				'name'			=> 'vertical_menu_3rd_google_fonts',
				'default_value'	=> '-1',
				'label'			=> esc_html__('Font Family', 'blu'),
				'parent'		=> $row_vertical_third_level_2
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'selectblanksimple',
				'name'			=> 'vertical_menu_3rd_fontstyle',
				'default_value'	=> '',
				'label'			=> esc_html__('Font Style', 'blu'),
				'options'		=> blu_elated_get_font_style_array(),
				'parent'		=> $row_vertical_third_level_2
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'selectblanksimple',
				'name'			=> 'vertical_menu_3rd_fontweight',
				'default_value'	=> '',
				'label'			=> esc_html__('Font Weight', 'blu'),
				'options'		=> blu_elated_get_font_weight_array(),
				'parent'		=> $row_vertical_third_level_2
			));

			$row_vertical_third_level_3 = blu_elated_add_admin_row(array(
				'name'		=> 'row_vertical_third_level_3',
				'parent'	=> $group_vertical_third_level,
				'next'		=> true
			));

			blu_elated_add_admin_field(array(
				'type'			=> 'textsimple',
				'name'			=> 'vertical_menu_3rd_letter_spacing',
				'default_value'	=> '',
				'label'			=> esc_html__('Letter Spacing', 'blu'),
				'args'			=> array(
					'suffix'	=> 'px'
				),
				'parent'		=> $row_vertical_third_level_3
			));

		/****************** Vertical Main Menu Layout ********************/
		
		
		$panel_mobile_header = blu_elated_add_admin_panel(array(
			'title' => esc_html__('Mobile Header', 'blu'),
			'name'  => 'panel_mobile_header',
			'page'  => '_header_page'
		));
		
		$mobile_header_group = blu_elated_add_admin_group(
			array(
				'parent' => $panel_mobile_header,
				'name' => 'mobile_header_group',
				'title' => esc_html__('Mobile Header Styles', 'blu')
			)
		);
		
		$mobile_header_row1 = blu_elated_add_admin_row(
			array(
				'parent' => $mobile_header_group,
				'name' => 'mobile_header_row1'
			)
		);
		
		blu_elated_add_admin_field(array(
			'name'        => 'mobile_header_height',
			'type'        => 'textsimple',
			'label'       => esc_html__('Height', 'blu'),
			'parent'      => $mobile_header_row1,
			'args'        => array(
				'col_width' => 3,
				'suffix'    => 'px'
			)
		));
		
		blu_elated_add_admin_field(array(
			'name'        => 'mobile_header_background_color',
			'type'        => 'colorsimple',
			'label'       => esc_html__('Background Color', 'blu'),
			'parent'      => $mobile_header_row1
		));
		
		blu_elated_add_admin_field(array(
			'name'        => 'mobile_header_border_bottom_color',
			'type'        => 'colorsimple',
			'label'       => esc_html__('Border Bottom Color', 'blu'),
			'parent'      => $mobile_header_row1
		));
		
		$mobile_menu_group = blu_elated_add_admin_group(
			array(
				'parent' => $panel_mobile_header,
				'name' => 'mobile_menu_group',
				'title' => esc_html__('Mobile Menu Styles', 'blu')
			)
		);
		
		$mobile_menu_row1 = blu_elated_add_admin_row(
			array(
				'parent' => $mobile_menu_group,
				'name' => 'mobile_menu_row1'
			)
		);
		
		blu_elated_add_admin_field(array(
			'name'        => 'mobile_menu_background_color',
			'type'        => 'colorsimple',
			'label'       => esc_html__('Background Color', 'blu'),
			'parent'      => $mobile_menu_row1
		));
		
		blu_elated_add_admin_field(array(
			'name'        => 'mobile_menu_border_bottom_color',
			'type'        => 'colorsimple',
			'label'       => esc_html__('Border Bottom Color', 'blu'),
			'parent'      => $mobile_menu_row1
		));
		
		blu_elated_add_admin_field(array(
			'name'        => 'mobile_menu_separator_color',
			'type'        => 'colorsimple',
			'label'       => esc_html__('Menu Item Separator Color', 'blu'),
			'parent'      => $mobile_menu_row1
		));
		
		blu_elated_add_admin_field(array(
			'name'        => 'mobile_logo_height',
			'type'        => 'text',
			'label'       => esc_html__('Logo Height For Mobile Header', 'blu'),
			'description' => esc_html__('Define logo height for screen size smaller than 1024px', 'blu'),
			'parent'      => $panel_mobile_header,
			'args'        => array(
				'col_width' => 3,
				'suffix'    => 'px'
			)
		));
		
		blu_elated_add_admin_field(array(
			'name'        => 'mobile_logo_height_phones',
			'type'        => 'text',
			'label'       => esc_html__('Logo Height For Mobile Devices', 'blu'),
			'description' => esc_html__('Define logo height for screen size smaller than 480px', 'blu'),
			'parent'      => $panel_mobile_header,
			'args'        => array(
				'col_width' => 3,
				'suffix'    => 'px'
			)
		));
		
		blu_elated_add_admin_section_title(array(
			'parent' => $panel_mobile_header,
			'name'   => 'mobile_header_fonts_title',
			'title'  => esc_html__('Typography', 'blu')
		));
		
			$first_level_group = blu_elated_add_admin_group(
				array(
					'parent' => $panel_mobile_header,
					'name' => 'first_level_group',
					'title' => esc_html__('1st Level Menu', 'blu'),
					'description' => esc_html__('Define styles for 1st level in Mobile Menu Navigation', 'blu')
				)
			);
		
				$first_level_row1 = blu_elated_add_admin_row(
					array(
						'parent' => $first_level_group,
						'name' => 'first_level_row1'
					)
				);
		
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_text_color',
						'type'        => 'colorsimple',
						'label'       => esc_html__('Text Color', 'blu'),
						'parent'      => $first_level_row1
					));
					
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_text_hover_color',
						'type'        => 'colorsimple',
						'label'       => esc_html__('Hover/Active Text Color', 'blu'),
						'parent'      => $first_level_row1
					));
					
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_font_family',
						'type'        => 'fontsimple',
						'label'       => esc_html__('Font Family', 'blu'),
						'parent'      => $first_level_row1
					));
					
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_font_size',
						'type'        => 'textsimple',
						'label'       => esc_html__('Font Size', 'blu'),
						'parent'      => $first_level_row1,
						'args'        => array(
							'col_width' => 3,
							'suffix'    => 'px'
						)
					));
		
				$first_level_row2 = blu_elated_add_admin_row(
					array(
						'parent' => $first_level_group,
						'name' => 'first_level_row2'
					)
				);
		
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_line_height',
						'type'        => 'textsimple',
						'label'       => esc_html__('Line Height', 'blu'),
						'parent'      => $first_level_row2,
						'args'        => array(
							'col_width' => 3,
							'suffix'    => 'px'
						)
					));
					
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_text_transform',
						'type'        => 'selectsimple',
						'label'       => esc_html__('Text Transform', 'blu'),
						'parent'      => $first_level_row2,
						'options'     => blu_elated_get_text_transform_array()
					));
					
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_font_style',
						'type'        => 'selectsimple',
						'label'       => esc_html__('Font Style', 'blu'),
						'parent'      => $first_level_row2,
						'options'     => blu_elated_get_font_style_array()
					));
					
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_font_weight',
						'type'        => 'selectsimple',
						'label'       => esc_html__('Font Weight', 'blu'),
						'parent'      => $first_level_row2,
						'options'     => blu_elated_get_font_weight_array()
					));
		
			$second_level_group = blu_elated_add_admin_group(
				array(
					'parent' => $panel_mobile_header,
					'name' => 'second_level_group',
					'title' => esc_html__('Dropdown Menu', 'blu'),
					'description' => esc_html__('Define styles for drop down menu items in Mobile Menu Navigation', 'blu')
				)
			);
			
				$second_level_row1 = blu_elated_add_admin_row(
					array(
						'parent' => $second_level_group,
						'name' => 'second_level_row1'
					)
				);
			
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_dropdown_text_color',
						'type'        => 'colorsimple',
						'label'       => esc_html__('Text Color', 'blu'),
						'parent'      => $second_level_row1
					));
					
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_dropdown_text_hover_color',
						'type'        => 'colorsimple',
						'label'       => esc_html__('Hover/Active Text Color', 'blu'),
						'parent'      => $second_level_row1
					));
					
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_dropdown_font_family',
						'type'        => 'fontsimple',
						'label'       => esc_html__('Font Family', 'blu'),
						'parent'      => $second_level_row1
					));
					
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_dropdown_font_size',
						'type'        => 'textsimple',
						'label'       => esc_html__('Font Size', 'blu'),
						'parent'      => $second_level_row1,
						'args'        => array(
							'col_width' => 3,
							'suffix'    => 'px'
						)
					));
			
				$second_level_row2 = blu_elated_add_admin_row(
					array(
						'parent' => $second_level_group,
						'name' => 'second_level_row2'
					)
				);
			
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_dropdown_line_height',
						'type'        => 'textsimple',
						'label'       => esc_html__('Line Height', 'blu'),
						'parent'      => $second_level_row2,
						'args'        => array(
							'col_width' => 3,
							'suffix'    => 'px'
						)
					));
					
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_dropdown_text_transform',
						'type'        => 'selectsimple',
						'label'       => esc_html__('Text Transform', 'blu'),
						'parent'      => $second_level_row2,
						'options'     => blu_elated_get_text_transform_array()
					));
					
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_dropdown_font_style',
						'type'        => 'selectsimple',
						'label'       => esc_html__('Font Style', 'blu'),
						'parent'      => $second_level_row2,
						'options'     => blu_elated_get_font_style_array()
					));
					
					blu_elated_add_admin_field(array(
						'name'        => 'mobile_dropdown_font_weight',
						'type'        => 'selectsimple',
						'label'       => esc_html__('Font Weight', 'blu'),
						'parent'      => $second_level_row2,
						'options'     => blu_elated_get_font_weight_array()
					));
		
			blu_elated_add_admin_section_title(array(
				'name' => 'mobile_opener_panel',
				'parent' => $panel_mobile_header,
				'title' => esc_html__('Mobile Menu Opener', 'blu')
			));
			
				blu_elated_add_admin_field(array(
					'name'        => 'mobile_menu_title',
					'type'        => 'text',
					'label'       => esc_html__('Mobile Navigation Title', 'blu'),
					'description' => esc_html__('Enter title for mobile menu navigation', 'blu'),
					'parent'      => $panel_mobile_header,
					'default_value' => esc_html__('Menu', 'blu'),
					'args' => array(
						'col_width' => 3
					)
				));
				
				blu_elated_add_admin_field(array(
					'name'        => 'mobile_icon_color',
					'type'        => 'color',
					'label'       => esc_html__('Mobile Navigation Icon Color', 'blu'),
					'parent'      => $panel_mobile_header
				));
				
				blu_elated_add_admin_field(array(
					'name'        => 'mobile_icon_hover_color',
					'type'        => 'color',
					'label'       => esc_html__('Mobile Navigation Icon Hover Color', 'blu'),
					'parent'      => $panel_mobile_header
				));
	}

	add_action( 'blu_elated_options_map', 'blu_elated_header_options_map', 3);
}