<?php
namespace BluElatedNamespace\Modules\Shortcodes\ElementsHolder;

use BluElatedNamespace\Modules\Shortcodes\Lib\ShortcodeInterface;

class ElementsHolder implements ShortcodeInterface{
	private $base;
	
	function __construct() {
		$this->base = 'eltdf_elements_holder';
		add_action('vc_before_init', array($this, 'vcMap'));
	}
	
	public function getBase() {
		return $this->base;
	}
	
	public function vcMap() {
		vc_map( array(
			'name' => esc_html__('Elated Elements Holder', 'blu'),
			'base' => $this->base,
			'icon' => 'icon-wpb-elements-holder extended-custom-icon',
			'category' => esc_html__('by ELATED', 'blu'),
			'as_parent' => array('only' => 'eltdf_elements_holder_item'),
			'js_view' => 'VcColumnView',
			'params' => array(
				array(
					'type'       => 'colorpicker',
					'param_name' => 'background_color',
					'heading'    => esc_html__('Background Color', 'blu')
				),
				array(
					'type'       => 'dropdown',
					'param_name' => 'number_of_columns',
					'heading'    => esc_html__('Columns', 'blu'),
					'value'      => array(
						esc_html__('1 Column', 'blu')  => 'one-column',
						esc_html__('2 Columns', 'blu') => 'two-columns',
						esc_html__('3 Columns', 'blu') => 'three-columns',
						esc_html__('4 Columns', 'blu') => 'four-columns',
						esc_html__('5 Columns', 'blu') => 'five-columns',
						esc_html__('6 Columns', 'blu') => 'six-columns'
					)
				),
				array(
					'type'       => 'checkbox',
					'param_name' => 'items_float_left',
					'heading'    => esc_html__('Items Float Left', 'blu'),
					'value'      => array('Make Items Float Left?' => 'yes')
				),
				array(
					'type'       => 'dropdown',
					'param_name' => 'switch_to_one_column',
					'heading'    => esc_html__('Switch to One Column', 'blu'),
					'value'      => array(
						esc_html__('Default', 'blu')   	=> '',
						esc_html__('Below 1280px', 'blu') 	=> '1280',
						esc_html__('Below 1024px', 'blu')  => '1024',
						esc_html__('Below 768px', 'blu')   => '768',
						esc_html__('Below 600px', 'blu')   => '600',
						esc_html__('Below 480px', 'blu')   => '480',
						esc_html__('Never', 'blu')    		=> 'never'
					),
					'description' => esc_html__('Choose on which stage item will be in one column', 'blu'),
					'save_always' => true
				),
				array(
					'type'       => 'dropdown',
					'param_name' => 'alignment_one_column',
					'heading'    => esc_html__('Choose Alignment In Responsive Mode', 'blu'),
					'value'      => array(
						esc_html__('Default', 'blu') => '',
						esc_html__('Left', 'blu') 	  => 'left',
						esc_html__('Center', 'blu')  => 'center',
						esc_html__('Right', 'blu')   => 'right'
					),
					'description' => esc_html__('Alignment When Items are in One Column', 'blu')
				)
			)
		));
	}

	public function render($atts, $content = null) {
		$args = array(
			'number_of_columns' 	=> '',
			'switch_to_one_column'	=> '',
			'alignment_one_column' 	=> '',
			'items_float_left' 		=> '',
			'background_color' 		=> ''
		);
		
		$params = shortcode_atts($args, $atts);
		extract($params);

		$html = '';

		$elements_holder_classes = array();
		$elements_holder_classes[] = 'eltdf-elements-holder';
		$elements_holder_style = '';

		if($number_of_columns != ''){
			$elements_holder_classes[] .= 'eltdf-'.$number_of_columns ;
		}

		if($switch_to_one_column != ''){
			$elements_holder_classes[] = 'eltdf-responsive-mode-' . $switch_to_one_column ;
		} else {
			$elements_holder_classes[] = 'eltdf-responsive-mode-768' ;
		}

		if($alignment_one_column != ''){
			$elements_holder_classes[] = 'eltdf-one-column-alignment-' . $alignment_one_column ;
		}

		if($items_float_left !== ''){
			$elements_holder_classes[] = 'eltdf-ehi-float';
		}

		if($background_color != ''){
			$elements_holder_style .= 'background-color:'. $background_color . ';';
		}

		$elements_holder_class = implode(' ', $elements_holder_classes);

		$html .= '<div ' . blu_elated_get_class_attribute($elements_holder_class) . ' ' . blu_elated_get_inline_attr($elements_holder_style, 'style'). '>';
			$html .= do_shortcode($content);
		$html .= '</div>';

		return $html;
	}
}
