<?php
class BluElatedClassButtonWidget extends BluElatedClassWidget {
	/**
	 * Set basic widget options and call parent class construct
	 */
	public function __construct() {
		parent::__construct(
			'eltdf_button_widget',
			esc_html__('Elated Button Widget', 'blu'),
			array( 'description' => esc_html__( 'Add buttons to widget areas', 'blu'))
		);

		$this->setParams();
	}

	/**
	 * Sets widget options
	 */
	protected function setParams() {
		$this->params = array(
			array(
				'type' => 'dropdown',
				'name' => 'type',
				'title' => esc_html__('Type', 'blu'),
				'options' => array(
					'solid' => esc_html__('Solid', 'blu'),
					'outline' => esc_html__('Outline', 'blu'),
					'simple' => esc_html__('Simple', 'blu')
				)
			),
			array(
				'type' => 'dropdown',
				'name' => 'size',
				'title' => esc_html__('Size', 'blu'),
				'options' => array(
					'small' => esc_html__('Small', 'blu'),
					'medium' => esc_html__('Medium', 'blu'),
					'large' => esc_html__('Large', 'blu'),
					'huge' => esc_html__('Huge', 'blu')
				),
				'description' => esc_html__('This option is only available for solid and outline button type', 'blu')
			),
			array(
				'type' => 'textfield',
				'name' => 'text',
				'title' => esc_html__('Text', 'blu'),
				'default' => esc_html__('Button Text', 'blu')
			),
			array(
				'type' => 'textfield',
				'name'  => 'link',
				'title' => esc_html__('Link', 'blu')
			),
			array(
				'type' => 'dropdown',
				'name' => 'target',
				'title' => esc_html__('Link Target', 'blu'),
				'options' => array(
					'_self' => esc_html__('Same Window', 'blu'),
					'_blank' => esc_html__('New Window', 'blu')
				)
			),
			array(
				'type' => 'textfield',
				'name' => 'color',
				'title' => esc_html__('Color', 'blu')
			),
			array(
				'type' => 'textfield',
				'name' => 'hover_color',
				'title' => esc_html__('Hover Color', 'blu')
			),
			array(
				'type' => 'textfield',
				'name' => 'background_color',
				'title' => esc_html__('Background Color', 'blu'),
				'description' => esc_html__('This option is only available for solid button type', 'blu')
			),
			array(
				'type' => 'textfield',
				'name' => 'hover_background_color',
				'title' => esc_html__('Hover Background Color', 'blu'),
				'description' => esc_html__('This option is only available for solid button type', 'blu')
			),
			array(
				'type' => 'textfield',
				'name' => 'border_color',
				'title' => esc_html__('Border Color', 'blu'),
				'description' => esc_html__('This option is only available for solid and outline button type', 'blu')
			),
			array(
				'type' => 'textfield',
				'name' => 'hover_border_color',
				'title' => esc_html__('Hover Border Color', 'blu'),
				'description' => esc_html__('This option is only available for solid and outline button type', 'blu')
			),
			array(
				'type' => 'textfield',
				'name' => 'margin',
				'title' => esc_html__('Margin', 'blu'),
				'description' => esc_html__('Insert margin in format: top right bottom left (e.g. 10px 5px 10px 5px)', 'blu')
			)
		);
	}

	/**
	 * Generates widget's HTML
	 *
	 * @param array $args args from widget area
	 * @param array $instance widget's options
	 */
	public function widget($args, $instance) {
		//prepare variables
		$params = '';

		if (!is_array($instance)) { $instance = array(); }

		// Filter out all empty params
		$instance = array_filter($instance, function($array_value) { return trim($array_value) != ''; });

		// Default values
		if (!isset($instance['text'])) { $instance['text'] = 'Button Text'; }

		// Generate shortcode params
		foreach($instance as $key => $value) {
			$params .= " $key='$value' ";
		}

		echo '<div class="widget eltdf-button-widget">';

			//finally call the shortcode
			echo do_shortcode("[eltdf_button $params]"); // XSS OK

		echo '</div>';
	}
}